import math
from PyQt5.QtCore import Qt
from PyQt5.QtGui import QPainter, QColor, QPalette, QBrush, QPen
from PyQt5.QtWidgets import QWidget


##############################################################################################
# Show a waiting indicator as an overlay.                                                    #
# Code taken from:                                                                           #
# https://wiki.python.org/moin/PyQt/A%20full%20widget%20waiting%20indicator                  #
##############################################################################################
class Overlay(QWidget):
    """
    Show a waiting indicator as an overlay.

    Code taken from:
    https://wiki.python.org/moin/PyQt/A%20full%20widget%20waiting%20indicator

    """

    def __init__(self, parent=None):

        QWidget.__init__(self, parent)
        palette = QPalette(self.palette())
        palette.setColor(palette.Background, Qt.transparent)
        self.setPalette(palette)

    def paintEvent(self, event):
        """
        Paint circles on screen as an waiting indicator for the user.

        :param event:   loading pdf
        :return:    None
        """
        self.resize(10000, 10000)
        painter = QPainter()
        painter.begin(self)
        painter.setRenderHint(QPainter.Antialiasing)
        painter.fillRect(50, 50, 100, 100, (QColor(255, 255, 255, 127)))
        painter.setPen(QPen(Qt.NoPen))

        for i in range(6):
            if (self.counter / 5) % 6 == i:
                painter.setBrush(QBrush(QColor(127 + (self.counter % 5) * 32, 12, 12)))
            else:
                painter.setBrush(QBrush(QColor(0.99 * 255, 0.36 * 255, 0.36 * 255)))
                painter.drawEllipse(
                    100 + 30 * math.cos(2 * math.pi * i / 6.0) - 10,
                    100 + 30 * math.sin(2 * math.pi * i / 6.0) - 10, 20, 20)
        painter.end()

    def showEvent(self, event):
        """
        Show the painted waiting indicator.

        :param event:   loading pdf
        :return:    None
        """
        self.timer = self.startTimer(40)
        self.counter = 0

    def timerEvent(self, event):
        """
        Timer for the duration of the indicator.

        :param event:   loading pdf
        :return:    None
        """
        self.counter += 1
        self.update()
        if self.counter == 40:
            self.killTimer(self.timer)
            self.hide()
